@@ -199,9 +199,7 @@ namespace Nereid
             footer_toolbar.ToolbarStyle = ToolbarStyle.BothHoriz;
 
             status_label = new Label ();
-            status_label.ModifyFg (StateType.Normal, Hyena.Gui.GtkUtilities.ColorBlend (
-                status_label.Style.Foreground (StateType.Normal), status_label.Style.Background (StateType.Normal)));
-
+            
             Alignment status_align = new Alignment (0.5f, 0.5f, 1.0f, 1.0f);
             status_align.Add (status_label);
 
@@ -234,6 +232,7 @@ namespace Nereid
         {
             // Service events
             ServiceManager.SourceManager.ActiveSourceChanged += OnActiveSourceChanged;
+            ServiceManager.SourceManager.SourceUpdated += OnSourceUpdated;
             ServiceManager.PlayerEngine.EventChanged += OnPlayerEngineEventChanged;
             
             ActionService.TrackActions ["SearchForSameArtistAction"].Activated += OnProgrammaticSearch;
@@ -297,16 +296,23 @@ namespace Nereid
             }
 
             // Connect the source models to the views if possible
-            if (source.Properties.Contains ("NereidSourceContents")) {
-                view_container.Content = source.Properties.Get<ISourceContents> ("NereidSourceContents");
+            if (source.Properties.Contains ("Nereid.SourceContents")) {
+                view_container.Content = source.Properties.Get<ISourceContents> ("Nereid.SourceContents");
                 view_container.Content.SetSource (source);
+                view_container.Show ();
             } else if (source is ITrackModelSource) {
                 if (composite_view.TrackModel != null) {
                     composite_view.TrackModel.Reloaded -= HandleTrackModelReloaded;
                 }
                 composite_view.SetSource (source);
                 composite_view.TrackModel.Reloaded += HandleTrackModelReloaded;
+                PersistentColumnController column_controller = 
+                    composite_view.TrackView.ColumnController as PersistentColumnController;
+                if (column_controller != null) {
+                    column_controller.Source = source;
+                }
                 view_container.Content = composite_view;
+                view_container.Show ();
             } else if (source is Hyena.Data.IObjectListModel) {
                 if (object_view == null) {
                     object_view = new ObjectListSourceContents ();
@@ -314,11 +320,24 @@ namespace Nereid
                 
                 view_container.Content = object_view;
                 view_container.Content.SetSource (source);
+                view_container.Show ();
+            } else {
+                view_container.Hide ();
             }
             
+            view_container.Header.Visible = source.Properties.Contains ("Nereid.SourceContents.HeaderVisible") ?
+                source.Properties.Get<bool> ("Nereid.SourceContents.HeaderVisible") : true;
+            
             UpdateStatusBar ();
             view_container.SearchEntry.Ready = true;
         }
+
+        private void OnSourceUpdated (SourceEventArgs args)
+        {
+            if (args.Source == ServiceManager.SourceManager.ActiveSource) {
+                UpdateStatusBar ();
+            }
+        }
         
         private void OnPlayerEngineEventChanged (object o, PlayerEngineEventArgs args) 
         {
