@@ -66,6 +66,7 @@ namespace Banshee.Collection
         private int play_count;
         private int skip_count;
         private DateTime last_played;
+        private DateTime last_skipped;
         
         private StreamPlaybackError playback_error = StreamPlaybackError.None;
 
@@ -75,9 +76,16 @@ namespace Banshee.Collection
 
         public virtual void IncrementPlayCount ()
         {
+            LastPlayed = DateTime.Now;
             PlayCount++;
         }
 
+        public virtual void IncrementSkipCount ()
+        {
+            LastSkipped = DateTime.Now;
+            SkipCount++;
+        }
+
         public override string ToString ()
         {
             return String.Format ("{0} - {1} (on {2}) <{3}> [{4}]", ArtistName, TrackTitle, 
@@ -246,6 +254,11 @@ namespace Banshee.Collection
             get { return last_played; }
             set { last_played = value; }
         }
+
+        public virtual DateTime LastSkipped {
+            get { return last_skipped; }
+            set { last_skipped = value; }
+        }
         
         public virtual StreamPlaybackError PlaybackError {
             get { return playback_error; }
@@ -273,6 +286,12 @@ namespace Banshee.Collection
             set { can_play = value; }
         }
         
+        private TrackMediaAttributes media_attributes;
+        public virtual TrackMediaAttributes MediaAttributes {
+            get { return media_attributes; }
+            set { media_attributes = value; }
+        }
+        
         // Generates a{sv} of self according to http://wiki.xmms2.xmms.se/index.php/Media_Player_Interfaces#.22Metadata.22
         public IDictionary<string, object> GenerateExportable ()
         {
