@@ -46,24 +46,22 @@ namespace Banshee.Library
 {
     public class LibrarySource : PrimarySource
     {
-        public LibrarySource () : base (Catalog.GetString ("Library"), Catalog.GetString ("Library"), "Library", 1)
+        public LibrarySource (string label, string name, int order) : base (label, label, name, order)
         {
-            Properties.SetStringList ("Icon.Name", "go-home", "user-home", "source-library");
             Properties.SetString ("GtkActionPath", "/LibraryContextMenu");
-            AfterInitialized ();
-
             Properties.SetString ("RemoveTracksActionLabel", Catalog.GetString ("Remove From Library"));
+            AfterInitialized ();
         }
         
         protected override void DeleteTrackRange (TrackListDatabaseModel model, RangeCollection.Range range)
         {
+            // Remove from file system
             for (int i = range.Start; i <= range.End; i++) {
                 DatabaseTrackInfo track = model [i] as DatabaseTrackInfo;
                 if (track == null)
                     continue;
 
                 try {
-                    // Remove from file system
                     try {
                         Banshee.IO.Utilities.DeleteFileTrimmingParentDirectories (track.Uri);
                     } catch (System.IO.FileNotFoundException) {
@@ -72,10 +70,10 @@ namespace Banshee.Library
                 } catch (Exception e) {
                     ErrorSource.AddMessage (e.Message, track.Uri.ToString ());
                 }
-
-                // Remove from database
-                RemoveTrackRange (model, range);
             }
+
+            // Remove from database
+            RemoveTrackRange (model, range);
         }
 
         public override bool AcceptsInputFromSource (Source source)
